<?php

namespace Drupal\twilio\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Utility\UrlHelper;
use Drupal\twilio\Controller\TwilioController;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\twilio\Services\Sms;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Messenger\Messenger;
use Drupal\user\Entity\User;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;

/**
 * Form to send test SMS messages.
 */
class UserSettingsForm extends FormBase {

  /**
   * Injected Twilio service Sms class.
   *
   * @var \Drupal\twilio\Services\Sms
   */
  private $sms;

  /**
   * User Account.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

   /**
   * Database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Messenger.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;


  /**
   * {@inheritdoc}
   */
  final public function __construct(Sms $sms, AccountInterface $account,Connection $connection,
  Messenger $messenger) {
    $this->sms = $sms;
    $this->account = $account;
    $this->connection = $connection;
    $this->messenger = $messenger;

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      // Load the service required to construct this class.
      $container->get('twilio.sms'),
      $container->get('current_user'),
      $container->get('database'),
      $container->get('messenger'),
    
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'twilio_user_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    // Changing the username in Drupal 8.
    
    
   // $user = User::load($this->account->id());
    $twilio_user = $this->sms->twilio_load($this->account->id());
    $form['uid'] = array(
      '#type' => 'hidden',
      '#value' => $this->account->id(),
    );
 
    if (empty($twilio_user['status'])) {
      $form['countrycode'] = array(
        '#type' => 'select',
        '#title' => $this->t('Country code'),
        '#options' =>  TwilioController::countryDialCodes(FALSE),
      );
      $form['number'] = array(
        '#type' => 'textfield',
        '#title' => t('Phone number'),
        '#description' => t('A confirmation code will be sent to via SMS to the number provided'),
        '#size' => 40,
        '#maxlength' => 255,
        '#required' => TRUE,
      );
      $form['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Send SMS'),
      ];
    }
    elseif ($twilio_user['status'] == 1) {
      $form['number'] = array(
        '#type' => 'item',
        '#title' => t('Mobile phone number'),
        '#markup' => $twilio_user['number'],
      );
      $form['confirm_code'] = array(
        '#type' => 'textfield',
        '#title' => t('Confirmation code'),
        '#description' => t('Enter the confirmation code sent by SMS to your mobile phone.'),
        '#size' => 4,
        '#maxlength' => 4,
        '#prefix' => '<div id="confirm-code"></div>',
      );
      $form['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Confirm number'),
      ];
     
    }
    elseif ($twilio_user['status'] == 2) {
      $form['twilio_user']['number'] = array(
        '#type' => 'item',
        '#title' => t('Your mobile phone number'),
        '#markup' => '+' . $twilio_user['country'] . ' ' . $twilio_user['number'],
        '#description' => t('Your mobile phone number has been confirmed.'),
      );
      $form['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Delete & start over'),
      ];
      
    }
    return $form;
  }






 

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $twilio_user = $this->sms->twilio_load($this->account->id());
    
   
    if ($form_state->getValue('submit') == 'Confirm number') {
      $value = $form_state->getValue('confirm_code');
     
      if ( $value != $twilio_user['code']) {
        $text = 'The confirmation code is invalid.';
        $form_state->setErrorByName('confirm_code', t($text));
      //  $ajax_response->addCommand(new HtmlCommand('#confirm-code', $text));
     }
    }
    
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    
    $twilio_user = $this->sms->twilio_load($this->account->id());
    if ($form_state->getValue('submit') == 'Delete & start over') {
      $this->sms->twilio_user_delete($this->account->id());
      $this->messenger->addMessage('Your mobile information has been removed..');

    }
    elseif($form_state->getValue('submit') == 'Send SMS') {
      \Drupal::service('twilio.sms')->twilio_user_send_confirmation($this->account, $form_state->getValue('number'), $form_state->getValue('countrycode'));
      $this->messenger->addStatus('Message has been send on your mobile number...');
    }
    else {
      $data = array(
        'number' => $twilio_user['number'],
        'status' => TWILIO_USER_CONFIRMED,
      );
      $this->sms->twilio_update ($data,$this->account->id());
      $this->messenger->addStatus('Your mobile number has been confirmed...');
    }
    
    
    
  }

}
